## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>", message = TRUE, warning = FALSE
)

## ----setup--------------------------------------------------------------------
library(PRONE)

## ----load_real_tmt------------------------------------------------------------
data("tuberculosis_TMT_se")
se <- tuberculosis_TMT_se

## ----eval = TRUE, include = FALSE---------------------------------------------
se <- subset_SE_by_norm(se, ain = c("raw", "log2"))

## -----------------------------------------------------------------------------
se_norm <- normalize_se(se, c("IRS_on_RobNorm", "IRS_on_Median", "IRS_on_LoessF", "IRS_on_Quantile"), combination_pattern = "_on_")

## -----------------------------------------------------------------------------
se_norm <- remove_reference_samples(se_norm)

## -----------------------------------------------------------------------------
comparisons <- specify_comparisons(se_norm, condition = "Group", sep = NULL, control = NULL)

comparisons <- c("PTB-HC", "TBL-HC", "TBL-PTB", "Rx-PTB")

## -----------------------------------------------------------------------------
de_res <- run_DE(se = se_norm, 
                     comparisons = comparisons,
                     ain = NULL, 
                     condition = NULL, 
                     DE_method = "limma", 
                     covariate = NULL, 
                     logFC = TRUE, 
                     logFC_up = 1, 
                     logFC_down = -1, 
                     p_adj = TRUE, 
                     alpha = 0.05,
                     trend = TRUE,
                     robust = TRUE,
                 ) 

## -----------------------------------------------------------------------------
new_de_res <- apply_thresholds(de_res = de_res, logFC = FALSE, p_adj = TRUE, alpha = 0.05)

## -----------------------------------------------------------------------------
plot_overview_DE_bar(de_res, ain = NULL, comparisons = comparisons, plot_type = "facet_regulation") + ggplot2::theme(legend.position = "bottom", legend.direction = "vertical")

## -----------------------------------------------------------------------------
plot_overview_DE_bar(de_res, ain = NULL, comparisons = comparisons[seq_len(2)], plot_type = "facet_comp")

## -----------------------------------------------------------------------------
plot_overview_DE_tile(de_res)

## -----------------------------------------------------------------------------
plot_volcano_DE(de_res, ain = NULL, comparisons = comparisons[1], facet_norm = TRUE)

## -----------------------------------------------------------------------------
plot_heatmap_DE(tuberculosis_TMT_se, tuberculosis_TMT_de_res, ain = NULL, comparison = "PTB-HC", condition = NULL, label_by = NULL, pvalue_column = "adj.P.Val")

## ----fig.height = 12----------------------------------------------------------
intersections <- plot_upset_DE(de_res, ain = NULL, comparisons = comparisons[seq_len(3)], min_degree = 6, plot_type = "stacked")
# put legend on top due to very long comparisons
intersections$upset[[2]] <- intersections$upset[[2]] + ggplot2::theme(legend.position = "top", legend.direction = "vertical")
intersections$upset

## -----------------------------------------------------------------------------
plot_jaccard_heatmap(de_res, ain = NULL, comparisons = comparisons, plot_type = "all")

## -----------------------------------------------------------------------------
DT::datatable(extract_consensus_DE_candidates(de_res, ain = NULL, comparisons = comparisons, norm_thr = 0.8, per_comparison = TRUE), options = list(scrollX = TRUE))

## -----------------------------------------------------------------------------
utils::sessionInfo()

