## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>", message = TRUE, warning = FALSE
)

## ----setup--------------------------------------------------------------------
library(PRONE)

## ----load_real_tmt------------------------------------------------------------
data("tuberculosis_TMT_se")
se <- tuberculosis_TMT_se

## ----eval = TRUE, include = FALSE---------------------------------------------
se <- subset_SE_by_norm(se, ain = c("raw", "log2"))

## -----------------------------------------------------------------------------
get_normalization_methods()

## -----------------------------------------------------------------------------
se_norm <- normalize_se(se, c("RobNorm", "Mean", "Median"), combination_pattern = NULL)

## -----------------------------------------------------------------------------
se_norm <- normalize_se(se, c("RobNorm", "Mean", "Median", "IRS_on_RobNorm", "IRS_on_Mean", "IRS_on_Median"), combination_pattern = "_on_")

## -----------------------------------------------------------------------------
se_norm <- medianNorm(se_norm, ain = "log2", aout = "Median")

## -----------------------------------------------------------------------------
names(SummarizedExperiment::assays(se_norm))

## ----fig.height = 12----------------------------------------------------------
plot_boxplots(se_norm, ain = NULL, color_by = NULL, label_by = NULL, ncol = 3, facet_norm = TRUE) + ggplot2::theme(legend.position = "bottom", legend.direction = "vertical")


## -----------------------------------------------------------------------------
plot_boxplots(se_norm, ain = c("IRS_on_RobNorm", "IRS_on_Median"), color_by = "Pool", label_by = NULL, facet_norm = TRUE)

## -----------------------------------------------------------------------------
plot_boxplots(se_norm, ain = c("IRS_on_RobNorm", "IRS_on_Median"), color_by = "Pool", label_by = NULL, facet_norm = FALSE)

## -----------------------------------------------------------------------------
plot_densities(se_norm, ain = c("IRS_on_RobNorm", "IRS_on_Median"), color_by = NULL, facet_norm = TRUE)

## -----------------------------------------------------------------------------
plot_PCA(se_norm, ain = c("IRS_on_RobNorm", "IRS_on_Median"), color_by = "Group", label_by = "No", shape_by = "Pool", facet_norm = FALSE, facet_by = "Group")

## -----------------------------------------------------------------------------
plot_PCA(se_norm, ain = c("IRS_on_RobNorm", "IRS_on_Median"), color_by = NULL, label_by = "No", shape_by = "Pool", facet_norm = TRUE) + ggplot2::theme(legend.position = "bottom", legend.direction = "vertical")

## -----------------------------------------------------------------------------
se_complete <- generate_complete_SE(se_norm, ain = NULL) # NULL -> all assays are taken

plot_PCA(se_complete, ain = NULL, color_by = "Normalization", label_by = "No", shape_by = "Pool", facet_norm = FALSE)

## -----------------------------------------------------------------------------
plot_intragroup_correlation(se_norm, ain = NULL, condition = NULL, method = "pearson")

## -----------------------------------------------------------------------------
plot_intragroup_PCV(se_norm, ain = NULL, condition = NULL, diff = FALSE)
plot_intragroup_PEV(se_norm, ain = NULL, condition = NULL, diff = FALSE)
plot_intragroup_PMAD(se_norm, ain = NULL, condition = NULL, diff = FALSE)

## -----------------------------------------------------------------------------
plot_intragroup_PCV(se_norm, ain = NULL, condition = NULL, diff = TRUE) 
plot_intragroup_PEV(se_norm, ain = NULL, condition = NULL, diff = TRUE)
plot_intragroup_PMAD(se_norm, ain = NULL, condition = NULL, diff = TRUE)

## -----------------------------------------------------------------------------
se_no_MAD <- remove_assays_from_SE(se_norm, assays_to_remove = c("MAD"))

## -----------------------------------------------------------------------------
se_subset <- subset_SE_by_norm(se_norm, ain = c("IRS_on_RobNorm", "IRS_on_Median"))

## -----------------------------------------------------------------------------
utils::sessionInfo()

