## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>", message = TRUE, warning = FALSE
)

## ----loading, eval = FALSE----------------------------------------------------
#  # Install PRONE.R from github and build vignettes
#  if (!requireNamespace("devtools", quietly = TRUE)) install.packages("devtools")
#  devtools::install_github("lisiarend/PRONE.R")

## ----library------------------------------------------------------------------
# Load and attach PRONE.R 
library("PRONE")

## ----load_real_tmt------------------------------------------------------------
data_path <- readPRONE_example("tuberculosis_TMT_proteinGroups.txt")
md_path <- readPRONE_example("tuberculosis_TMT_metadata.txt")

data <- read.csv(data_path, sep ="\t")
md <- read.csv(md_path, sep = "\t")

md$Column <- stringr::str_replace_all(md$Column, " ", ".")

ref_samples <- md[md$Group == "Common.reference",]$Column

se <- load_data(data, md, protein_column = "Protein.IDs", gene_column = "Gene.names", ref_samples = ref_samples, batch_column = "Pool", condition_column = "Group", label_column = "Label")


## ----load_real_lfq------------------------------------------------------------
data_path <- readPRONE_example("MouseP450_LFQ_protein_table.csv")
data <- read.csv(data_path, row.names = 1)

# Create metadata (since it was not given)
md <- data.frame(Column = colnames(data)[seq_len((ncol(data)-2))])
md$Animal <- sapply(strsplit(as.character(md$Column),"_"), "[", 1)
md$Condition <- sapply(strsplit(as.character(md$Column),"_"), "[", 2)

se <- load_data(data, md, protein_column = "Accession", gene_column = NULL, ref_samples = NULL, batch_column = NULL, condition_column = "Condition", label_column = NULL)

## -----------------------------------------------------------------------------
se

## -----------------------------------------------------------------------------
SummarizedExperiment::assays(se)

## -----------------------------------------------------------------------------
se <- normalize_se(se, c("Median", "LoessF"))

## -----------------------------------------------------------------------------
SummarizedExperiment::assays(se)

## ----eval = FALSE-------------------------------------------------------------
#  if(!dir.exists("output/")) dir.create("output/")
#  
#  export_data(se_norm, out_dir = "output/", ain = c("log2", "Median", "LoessF"))

## -----------------------------------------------------------------------------
utils::sessionInfo()

