## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>", message = TRUE, warning = FALSE
)

## ----setup--------------------------------------------------------------------
library(PRONE)

## ----load_real_tmt------------------------------------------------------------
data("tuberculosis_TMT_se")
se <- tuberculosis_TMT_se

## ----eval = TRUE, include = FALSE---------------------------------------------
se <- subset_SE_by_norm(se, ain = c("raw", "log2"))

## ----overview_NA_table--------------------------------------------------------
get_NA_overview(se, ain = "log2")

## ----overview_plots-----------------------------------------------------------
plot_condition_overview(se, condition = NULL)

plot_condition_overview(se, condition = "Pool")

## ----overview_heatmap---------------------------------------------------------
available_ains <- names(SummarizedExperiment::assays(se))

plot_heatmap(se, ain = "log2", color_by = c("Pool", "Group"), label_by = NULL, only_refs = FALSE)

## ----overview_upset, fig.width = 8, fig.height = 8----------------------------
plot_upset(se, color_by = NULL, label_by = NULL, mb.ratio = c(0.7,0.3), only_refs = FALSE)

## -----------------------------------------------------------------------------
p <- plot_markers_boxplots(se, markers = c("Q92954;J3KP74;E9PLR3", "Q9Y6Z7", "Q68CQ4"), ain = "log2", id_column = "Protein.IDs", facet_norm = FALSE, facet_marker = TRUE)
p[[1]] + ggplot2::theme(axis.text.x = ggplot2::element_text(angle = 90, vjust = 0.5))

## -----------------------------------------------------------------------------
se <- filter_out_complete_NA_proteins(se)

## -----------------------------------------------------------------------------
se <- filter_out_proteins_by_value(se, "Reverse", "+")
se <- filter_out_proteins_by_value(se, "Only.identified.by.site", "+")
#se <- filter_out_proteins_by_value(se, "Potential.contaminant", "+")

## -----------------------------------------------------------------------------
pot_contaminants <- get_proteins_by_value(se, "Potential.contaminant", "+")
se <- filter_out_proteins_by_ID(se, pot_contaminants)

## -----------------------------------------------------------------------------
plot_NA_heatmap(se, color_by = NULL, label_by = NULL, cluster_samples = TRUE, cluster_proteins = TRUE)

## -----------------------------------------------------------------------------
plot_NA_density(se)

## -----------------------------------------------------------------------------
plot_NA_frequency(se)

## -----------------------------------------------------------------------------
se <- filter_out_NA_proteins_by_threshold(se, thr = 0.7) 

plot_NA_heatmap(se)

## -----------------------------------------------------------------------------
plot_nr_prot_samples(se, color_by = NULL, label_by = NULL)

plot_tot_int_samples(se, color_by = NULL, label_by = NULL)

## -----------------------------------------------------------------------------
se <- remove_samples_manually(se, "Label", c("1.HC_Pool1", "1.HC_Pool2"))

## -----------------------------------------------------------------------------
se_no_refs <- remove_reference_samples(se)

## -----------------------------------------------------------------------------
poma_res <- detect_outliers_POMA(se, ain = "log2")

poma_res$polygon_plot

poma_res$distance_boxplot

DT::datatable(poma_res$outliers, options = list(scrollX = TRUE))

## -----------------------------------------------------------------------------
se <- remove_POMA_outliers(se, poma_res$outliers)

## -----------------------------------------------------------------------------
utils::sessionInfo()

