## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>", message = TRUE, warning = FALSE
)

## ----setup--------------------------------------------------------------------
library(PRONE)

## -----------------------------------------------------------------------------
data_path <- readPRONE_example("spike_in_proteinGroups.txt")
md_path <- readPRONE_example("spike_in_metadata.txt")

data <- read.csv(data_path, sep = "\t")
md <- read.csv(md_path, sep = "\t")

# Check if some protein groups are mixed
mixed <- grepl("Homo sapiens.*Escherichia|Escherichia.*Homo sapiens", data$Fasta.headers)
data <- data[!mixed,]

data$Spiked <- rep("HUMAN", nrow(data))
data$Spiked[grepl("ECOLI", data$Fasta.headers)] <- "ECOLI"

se <- load_spike_data(data, md, spike_column = "Spiked", spike_value = "ECOLI", spike_concentration = "Concentration",protein_column = "Protein.IDs", gene_column = "Gene.names", ref_samples = NULL, batch_column = NULL, condition_column = "Condition", label_column = "Label")

## -----------------------------------------------------------------------------
plot_identified_spiked_proteins(se)

## -----------------------------------------------------------------------------
plot_histogram_spiked(se, condition = NULL)

## -----------------------------------------------------------------------------
plot_profiles_spiked(se, xlab = "Concentration")

## -----------------------------------------------------------------------------
se_norm <- normalize_se(se, c("Median", "Mean", "MAD", "LoessF"), combination_pattern = NULL)

## -----------------------------------------------------------------------------
comparisons <- specify_comparisons(se_norm, condition = "Condition", sep = NULL, control = NULL)

## -----------------------------------------------------------------------------
de_res <- run_DE(se = se_norm, 
                     comparisons = comparisons,
                     ain = NULL, 
                     condition = NULL, 
                     DE_method = "limma", 
                     covariate = NULL, 
                     logFC = TRUE, 
                     logFC_up = 1, 
                     logFC_down = -1, 
                     p_adj = TRUE, 
                     alpha = 0.05, 
                     B = 100, 
                     K = 500)

## -----------------------------------------------------------------------------
stats <- get_spiked_stats_DE(se_norm, de_res)

## -----------------------------------------------------------------------------
plot_TP_FP_spiked_bar(stats, ain = c("Median", "Mean", "MAD", "LoessF"), comparisons = NULL)

## -----------------------------------------------------------------------------
plot_TP_FP_spiked_box(stats, ain = c("Median", "Mean", "MAD", "LoessF"), comparisons = NULL)

## -----------------------------------------------------------------------------
plot_TP_FP_spiked_scatter(stats, ain = NULL, comparisons = NULL)

## -----------------------------------------------------------------------------
plot_stats_spiked_heatmap(stats, ain = c("Median", "Mean", "MAD"), metrics = c("Precision", "F1Score"))

## -----------------------------------------------------------------------------
plot_ROC_AUC_spiked(se_norm, de_res, ain = c("Median", "Mean", "LoessF"), comparisons = NULL)

## -----------------------------------------------------------------------------
plot_fold_changes_spiked(se_norm, de_res, condition = "Condition", ain = c("Median", "Mean", "MAD"), comparisons = NULL)

## -----------------------------------------------------------------------------
plot_pvalues_spiked(se_norm, de_res, ain = c("Median", "Mean", "MAD"), comparisons = NULL)

## -----------------------------------------------------------------------------
plot_logFC_thresholds_spiked(se_norm, de_res, condition = NULL, ain = c("Median", "Mean", "MAD"), nrow = 1, alpha = 0.05)

## -----------------------------------------------------------------------------
utils::sessionInfo()

